# About PTO (Planner of Transit Observations):
`PTO` is a code that allows the user to calculate transit windows and plot their visibility for given location. Currently, main focus of `PTO` is handling high-resolution observations of transits, but further extensions can be made.

Furthermore, sample selection can be done easily through the NASA Exoplanet archive tables, as these are automatically downloaded by `PTO`.



